@@ -38,7 +38,7 @@
  *           mmclennan@lucent.com
  *           http://www.tcltk.com/itcl
  *
- *     RCS:  $Id: itk.h,v 1.5 1999/05/24 21:10:47 redman Exp $
+ *     RCS:  $Id: itk.h,v 1.9 2001/05/25 00:15:04 davygrvy Exp $
  * ========================================================================
  *           Copyright (c) 1993-1998  Lucent Technologies, Inc.
  * ------------------------------------------------------------------------
@@ -55,7 +55,7 @@
  * and procedure declarations, that occur below.
  */
 
-#ifndef RESOURCE_INCLUDED
+#ifndef RC_INVOKED
 
 #include "itclInt.h"
 #include "tk.h"
@@ -95,8 +95,22 @@ typedef struct ItkClassOption {
 
 #include "itkDecls.h"
 
+/*
+ *  This function is contained in the itkstub static library
+ */
+
+#ifdef USE_ITK_STUBS
+
+CONST char *		Itk_InitStubs _ANSI_ARGS_((Tcl_Interp *interp,
+			    char *version, int exact));
+#endif
+
+/*
+ * Public functions that are not accessible via the stubs table.
+ */
+
 # undef TCL_STORAGE_CLASS
 # define TCL_STORAGE_CLASS DLLIMPORT
 
-#endif /* RESOURCE INCLUDED */
+#endif /* RC_INVOKED */
 #endif /* ITK_H */
